@@ -15,21 +15,19 @@ my $d = MIDI::Drummer::Tiny->new(
 );
 
 $d->sync(
-    \&hhat,
     \&snare,
     \&kick,
+    \&hhat,
 );
 
 $d->write;
 
 sub snare {
-    $d->combinatorial( $d->snare );
+    $d->combinatorial( $d->snare, { count => 1 } );
 }
 
 sub kick {
-    $d->combinatorial( $d->kick, {
-        negate => 1,
-    });
+    $d->combinatorial( $d->kick, { negate => 1 } );
 }
 
 sub hhat {
