@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Glorified metronome
 
-our $VERSION = '0.2006';
+our $VERSION = '0.2007';
 
 use Algorithm::Combinatorics qw(variations_with_repetition);
 use MIDI::Util qw(dura_size);
@@ -468,7 +468,7 @@ MIDI::Drummer::Tiny - Glorified metronome
 
 =head1 VERSION
 
-version 0.2006
+version 0.2007
 
 =head1 SYNOPSIS
 
@@ -505,6 +505,14 @@ version 0.2006
  $d->note($d->quarter, $d->open_hh, $_ % 2 ? $d->kick : $d->snare)
     for 1 .. $d->beats * $d->bars;
 
+ $d->combinatorial( $d->snare, { patterns => [qw(0101 1001)] } );
+
+ # Play parts simultaneously
+ $d->sync( \&snare, \&kick, \&hhat );
+ sub snare { $d->combinatorial( $d->snare, { count => 1 } ) }
+ sub kick { $d->combinatorial( $d->kick, { negate => 1 } ) }
+ sub hhat { $d->steady( $d->closed_hh ) }
+
  $d->write;
 
 =head1 DESCRIPTION
@@ -512,6 +520,9 @@ version 0.2006
 This module provides handy defaults and tools to produce a MIDI score
 with drum parts.
 
+Below, the term "spec" refers to a note length duration, like an
+eighth or quarter note, for instance.
+
 =for Pod::Coverage BUILD
 
 =head1 ATTRIBUTES
@@ -837,7 +848,7 @@ Play a beat pattern with the given B<instrument>, given by
 L<Algorithm::Combinatorics/variations_with_repetition>.
 
 This method accumulates beats in the object's B<counter> attribute if
-the B<count> option is set..
+the B<count> option is set.
 
 The B<vary> option is a hashref of coderefs, keyed by single character
 tokens, like the digits, 0-9.  The coderef durations should add up to
